import puppeteer from 'puppeteer';
import { AxeResults } from 'axe-core';
export declare type Options = {
    pageLimit: number;
    maxRetries?: number;
    ignoreFragmentLinks?: boolean;
    ignoreExtensions?: Array<string>;
    ignoreQueryParams?: boolean;
    routeManifestPath?: string;
    streaming?: boolean;
    puppeteerChromeLaunchArgs?: puppeteer.LaunchOptions['args'];
};
declare type CoreReturnValue = {
    type: 'state';
    data: StateData;
} | {
    type: 'results';
    data: AxeResults;
};
declare type StateData = {
    entry: string;
    options: Options;
    run: number;
    routes: any;
    pagesVisited: string[];
    routesVisited: string[];
    toVisit: string[];
};
/**
 * Runs the assertions at the URL with options, and returns them all at once.
 *
 * This version is simpler to use (you await it), but it might have memory
 * pressure issues.
 *
 * An alternative is runCoreStreaming, which returns results one-at-a-time.
 */
export declare function runCore(rootURL: URL, opts: Options): Promise<{
    state: {} | StateData;
    results: AxeResults[];
}>;
/**
 * Runs the assertions at the URL with options, and returns them one-at-a-time,
 * as an async iterable.
 *
 * This version allows you to process results at your own pace, which can be
 * good for memory pressure, as well as implementing other streaming interfaces
 * on top.
 *
 * An alternative is runCore, which buffers / collects the results instead.
 *
 * @see https://2ality.com/2016/10/asynchronous-iteration.html
 * @see http://javascript.info/async-iterators-generators
 */
export declare function runCoreStreaming(rootURL: URL, opts: Options): {
    [Symbol.asyncIterator](): AsyncGenerator<CoreReturnValue, any, unknown>;
};
export {};
